unit fonttbl;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, StdCtrls,
  Buttons, ExtCtrls, pgobj, Dialogs;

type
  TFontTblDlg = class(TForm)
    OKBtn: TButton;
    CancelBtn: TButton;
    FntList: TListBox;
    FontSel: TFontDialog;
    procedure FntListDblClick(Sender: TObject);
    procedure FntListDrawItem(Control: TWinControl; Index: Integer;
      Rect: TRect; State: TOwnerDrawState);
    procedure FntListMeasureItem(Control: TWinControl; Index: Integer;
      var Height: Integer);
    procedure OKBtnClick(Sender: TObject);
  private
    Ftpl: ttemplate;
    FRepName: string;
    procedure RefreshList;
    destructor Destroy; override;
  public
    constructor Create(AOwner: TComponent; RepName: string);
  end;

var
  FontTblDlg: TFontTblDlg;

implementation

{$R *.DFM}

constructor TFontTblDlg.Create(AOwner: TComponent; RepName: string);
var f: tfilestream;
begin
  inherited Create(AOwner);
  ftpl:=nil;
  FRepName:=RepName;
  F := TFileStream.Create(repname, fmOpenRead);
  try
    ftpl:=ttemplate.loadfromstream(f);
  finally
    F.Free;
  end;
  if ftpl<>nil then refreshlist;
end;

destructor TFontTblDlg.Destroy;
begin
  if ftpl<>nil then ftpl.free;
  inherited;
end;

procedure TFontTblDlg.RefreshList;
var i,j: integer;
begin
  j:=FntList.itemindex;
  FntList.clear;
  for i:=1 to ftpl.fontmap.count do FntList.items.add('');
  FntList.itemindex:=j;
end;

procedure TFontTblDlg.FntListDblClick(Sender: TObject);
var fi: tfontitem;
begin
  fi := tfontitem(ftpl.fontmap.items[FntList.itemindex]);
  FontSel.Font.name:=fi.fontname;
  FontSel.Font.size:=fi.fontsize;
  FontSel.Font.style:=fi.fontstyle;
  if FontSel.Execute then
  begin
    fi.fontname:=FontSel.Font.name;
    fi.fontsize:=FontSel.Font.size;
    fi.fontstyle:=FontSel.Font.style;
  end;
  refreshlist;
end;

procedure TFontTblDlg.FntListDrawItem(Control: TWinControl; Index: Integer;
  Rect: TRect; State: TOwnerDrawState);
begin
  with FntList.Canvas do
  begin
    FillRect(Rect);
    Font.Name :=tfontitem(ftpl.fontmap.items[index]).fontname;
    Font.size :=tfontitem(ftpl.fontmap.items[index]).fontsize;
    Font.style :=tfontitem(ftpl.fontmap.items[index]).fontstyle;
    TextOut(Rect.Left+1, Rect.Top+1, tfontitem(ftpl.Fontmap.Items[Index]).descr);
  end;
end;

procedure TFontTblDlg.FntListMeasureItem(Control: TWinControl;
  Index: Integer; var Height: Integer);
begin
  with FntList.Canvas do
  begin
    Font.Name :=tfontitem(ftpl.fontmap.items[index]).fontname;
    Font.size :=tfontitem(ftpl.fontmap.items[index]).fontsize;
    Font.style :=tfontitem(ftpl.fontmap.items[index]).fontstyle;
    Height := TextHeight('Wg') + 2; // measure ascenders and descenders
  end;
end;

procedure TFontTblDlg.OKBtnClick(Sender: TObject);
var f: tfilestream;
begin
  if ftpl<>nil then begin
    F := TFileStream.Create(FRepName, fmCreate);
    try
      ftpl.storetostream(f);
    finally
      F.Free;
    end;
  end;
end;

end.
